@@ -2,7 +2,7 @@
 """
 import logging, os, sys, shutil, urllib2
 
-BOOTSTRAP_URL = 'http://svn.zope.org/*checkout*/zc.buildout/trunk/bootstrap/bootstrap.py'
+BOOTSTRAP_URL = 'http://python-distribute.org/bootstrap.py'
 
 
 logger = logging.getLogger('migrator')
