@@ -83,7 +83,6 @@ class ExternalMethod:
         self.out_file = options['output']
         self.no_copy = options.get('no_copy', False)
         self.loop = options.get('loop', False)
-        self.no_create = options.get('no_create', False)
         self.path = os.path.join(buildout['buildout']['directory'], 'parts', self.name)
         self.args = {}
         if 'args' in options:
@@ -94,18 +93,17 @@ class ExternalMethod:
         """ copy file, create external method and run it """
         local_instance = {}
         local_instance['host'] = 'localhost'
-        if not (self.no_create or self.no_copy):
+        if not self.no_copy:
             if not utils.create_dir(self.instance, self.instance['extensions']):
                 raise zc.buildout.UserError('Cannot mkdir')
             if utils.copy_file(local_instance, self.source_dir, self.source_file,
                         self.instance, self.instance['extensions'], keep=True) < 0:
                 raise zc.buildout.UserError('Could not copy script')
         br = utils.get_browser(self.instance)
-        if not self.no_create:
-            rc = utils.create_ext_method(self.instance, self.source_file, self.function, br)
-            if rc:
-                logging.getLogger(self.name).error('Error running %s: %s.', self.function, rc)
-                raise zc.buildout.UserError('Create Ext Method')
+        rc = utils.create_ext_method(self.instance, self.source_file, self.function, br)
+        if rc:
+            logging.getLogger(self.name).error('Error running %s: %s.', self.function, rc)
+            raise zc.buildout.UserError('Create Ext Method')
         if self.loop:
             loop = self.args[self.loop]
             for arg in loop.split():
